summaryrefslogtreecommitdiff
path: root/actions/showgroup.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@status.net>2009-08-27 11:16:45 -0700
committerEvan Prodromou <evan@status.net>2009-08-27 11:16:45 -0700
commit5d09b6b3f0595540c66b703ae085f0af904fe30f (patch)
tree59269a4dacf90bbab9f0ff63afff4bf1781a1240 /actions/showgroup.php
parentf1fda6c0503e32edfc99b297f4bf2cb07e629d9e (diff)
parent82b0927f5838f3c12816e03712df9460a9f77b72 (diff)
Merge branch '0.8.x' into 0.9.x
Conflicts: EVENTS.txt actions/finishremotesubscribe.php actions/postnotice.php actions/public.php actions/remotesubscribe.php actions/showstream.php actions/updateprofile.php actions/userauthorization.php classes/laconica.ini lib/common.php lib/oauthstore.php lib/omb.php
Diffstat (limited to 'actions/showgroup.php')
-rw-r--r--actions/showgroup.php24
1 files changed, 12 insertions, 12 deletions
diff --git a/actions/showgroup.php b/actions/showgroup.php
index c3471c195..ff9949762 100644
--- a/actions/showgroup.php
+++ b/actions/showgroup.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Group main page
*
@@ -20,15 +20,15 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Group
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @author Sarven Capadisli <csarven@controlyourself.ca>
- * @copyright 2008-2009 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @author Sarven Capadisli <csarven@status.net>
+ * @copyright 2008-2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -41,10 +41,10 @@ define('MEMBERS_PER_SECTION', 27);
* Group main page
*
* @category Group
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
class ShowgroupAction extends GroupDesignAction
@@ -448,13 +448,13 @@ class ShowgroupAction extends GroupDesignAction
{
if (!(common_config('site','closed') || common_config('site','inviteonly'))) {
$m = sprintf(_('**%s** is a user group on %%%%site.name%%%%, a [micro-blogging](http://en.wikipedia.org/wiki/Micro-blogging) service ' .
- 'based on the Free Software [Laconica](http://laconi.ca/) tool. Its members share ' .
+ 'based on the Free Software [StatusNet](http://status.net/) tool. Its members share ' .
'short messages about their life and interests. '.
'[Join now](%%%%action.register%%%%) to become part of this group and many more! ([Read more](%%%%doc.help%%%%))'),
$this->group->nickname);
} else {
$m = sprintf(_('**%s** is a user group on %%%%site.name%%%%, a [micro-blogging](http://en.wikipedia.org/wiki/Micro-blogging) service ' .
- 'based on the Free Software [Laconica](http://laconi.ca/) tool. Its members share ' .
+ 'based on the Free Software [StatusNet](http://status.net/) tool. Its members share ' .
'short messages about their life and interests. '),
$this->group->nickname);
}
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Group main page